[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Build Status](https://travis-ci.org/pmeier/pyimagetest.svg?branch=master)](https://travis-ci.org/pmeier/pyimagetest) [![codecov](https://codecov.io/gh/pmeier/pyimagetest/branch/master/graph/badge.svg)](https://codecov.io/gh/pmeier/pyimagetest) [![Documentation Status](https://readthedocs.org/projects/pyimagetest/badge/?version=latest)](https://pyimagetest.readthedocs.io/en/latest/?badge=latest)

# pyimagetest

`pyimagetest` provides utilities for unit testing with images. 

For installation instructions and usage examples please consult the documentation [hosted on readthedocs.com](https://pyimagetest.readthedocs.io/en/latesthttps://pyimagetest.readthedocs.io/en/latest).
